# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import arlas_tagger_api_python
from arlas_tagger_api_python.rest import ApiException
from arlas_tagger_api_python.models.propagation import Propagation


class TestPropagation(unittest.TestCase):
    """ Propagation unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPropagation(self):
        """
        Test Propagation
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = arlas_tagger_api_python.models.propagation.Propagation()
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Form(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pretty': 'bool',
        'flat': 'bool'
    }

    attribute_map = {
        'pretty': 'pretty',
        'flat': 'flat'
    }

    def __init__(self, pretty=None, flat=None):
        """
        Form - a model defined in Swagger
        """

        self._pretty = None
        self._flat = None

        if pretty is not None:
          self.pretty = pretty
        if flat is not None:
          self.flat = flat

    @property
    def pretty(self):
        """
        Gets the pretty of this Form.

        :return: The pretty of this Form.
        :rtype: bool
        """
        return self._pretty

    @pretty.setter
    def pretty(self, pretty):
        """
        Sets the pretty of this Form.

        :param pretty: The pretty of this Form.
        :type: bool
        """

        self._pretty = pretty

    @property
    def flat(self):
        """
        Gets the flat of this Form.

        :return: The flat of this Form.
        :rtype: bool
        """
        return self._flat

    @flat.setter
    def flat(self, flat):
        """
        Sets the flat of this Form.

        :param flat: The flat of this Form.
        :type: bool
        """

        self._flat = flat

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Form):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import arlas_tagger_api_python
from arlas_tagger_api_python.rest import ApiException
from arlas_tagger_api_python.apis.status_api import StatusApi


class TestStatusApi(unittest.TestCase):
    """ StatusApi unit test stubs """

    def setUp(self):
        self.api = arlas_tagger_api_python.apis.status_api.StatusApi()

    def tearDown(self):
        pass

    def test_tagging_get(self):
        """
        Test case for tagging_get

        TagStatus
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Search(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter': 'Filter',
        'form': 'Form',
        'page': 'Page',
        'projection': 'Projection'
    }

    attribute_map = {
        'filter': 'filter',
        'form': 'form',
        'page': 'page',
        'projection': 'projection'
    }

    def __init__(self, filter=None, form=None, page=None, projection=None):
        """
        Search - a model defined in Swagger
        """

        self._filter = None
        self._form = None
        self._page = None
        self._projection = None

        if filter is not None:
          self.filter = filter
        if form is not None:
          self.form = form
        if page is not None:
          self.page = page
        if projection is not None:
          self.projection = projection

    @property
    def filter(self):
        """
        Gets the filter of this Search.

        :return: The filter of this Search.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this Search.

        :param filter: The filter of this Search.
        :type: Filter
        """

        self._filter = filter

    @property
    def form(self):
        """
        Gets the form of this Search.

        :return: The form of this Search.
        :rtype: Form
        """
        return self._form

    @form.setter
    def form(self, form):
        """
        Sets the form of this Search.

        :param form: The form of this Search.
        :type: Form
        """

        self._form = form

    @property
    def page(self):
        """
        Gets the page of this Search.

        :return: The page of this Search.
        :rtype: Page
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this Search.

        :param page: The page of this Search.
        :type: Page
        """

        self._page = page

    @property
    def projection(self):
        """
        Gets the projection of this Search.

        :return: The projection of this Search.
        :rtype: Projection
        """
        return self._projection

    @projection.setter
    def projection(self, projection):
        """
        Sets the projection of this Search.

        :param projection: The projection of this Search.
        :type: Projection
        """

        self._projection = projection

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Search):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Filter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'f': 'list[list[Expression]]',
        'q': 'list[list[str]]',
        'pwithin': 'list[list[str]]',
        'gwithin': 'list[list[str]]',
        'gintersect': 'list[list[str]]',
        'notpwithin': 'list[list[str]]',
        'notgwithin': 'list[list[str]]',
        'notgintersect': 'list[list[str]]',
        'dateformat': 'str'
    }

    attribute_map = {
        'f': 'f',
        'q': 'q',
        'pwithin': 'pwithin',
        'gwithin': 'gwithin',
        'gintersect': 'gintersect',
        'notpwithin': 'notpwithin',
        'notgwithin': 'notgwithin',
        'notgintersect': 'notgintersect',
        'dateformat': 'dateformat'
    }

    def __init__(self, f=None, q=None, pwithin=None, gwithin=None, gintersect=None, notpwithin=None, notgwithin=None, notgintersect=None, dateformat=None):
        """
        Filter - a model defined in Swagger
        """

        self._f = None
        self._q = None
        self._pwithin = None
        self._gwithin = None
        self._gintersect = None
        self._notpwithin = None
        self._notgwithin = None
        self._notgintersect = None
        self._dateformat = None

        if f is not None:
          self.f = f
        if q is not None:
          self.q = q
        if pwithin is not None:
          self.pwithin = pwithin
        if gwithin is not None:
          self.gwithin = gwithin
        if gintersect is not None:
          self.gintersect = gintersect
        if notpwithin is not None:
          self.notpwithin = notpwithin
        if notgwithin is not None:
          self.notgwithin = notgwithin
        if notgintersect is not None:
          self.notgintersect = notgintersect
        if dateformat is not None:
          self.dateformat = dateformat

    @property
    def f(self):
        """
        Gets the f of this Filter.

        :return: The f of this Filter.
        :rtype: list[list[Expression]]
        """
        return self._f

    @f.setter
    def f(self, f):
        """
        Sets the f of this Filter.

        :param f: The f of this Filter.
        :type: list[list[Expression]]
        """

        self._f = f

    @property
    def q(self):
        """
        Gets the q of this Filter.

        :return: The q of this Filter.
        :rtype: list[list[str]]
        """
        return self._q

    @q.setter
    def q(self, q):
        """
        Sets the q of this Filter.

        :param q: The q of this Filter.
        :type: list[list[str]]
        """

        self._q = q

    @property
    def pwithin(self):
        """
        Gets the pwithin of this Filter.

        :return: The pwithin of this Filter.
        :rtype: list[list[str]]
        """
        return self._pwithin

    @pwithin.setter
    def pwithin(self, pwithin):
        """
        Sets the pwithin of this Filter.

        :param pwithin: The pwithin of this Filter.
        :type: list[list[str]]
        """

        self._pwithin = pwithin

    @property
    def gwithin(self):
        """
        Gets the gwithin of this Filter.

        :return: The gwithin of this Filter.
        :rtype: list[list[str]]
        """
        return self._gwithin

    @gwithin.setter
    def gwithin(self, gwithin):
        """
        Sets the gwithin of this Filter.

        :param gwithin: The gwithin of this Filter.
        :type: list[list[str]]
        """

        self._gwithin = gwithin

    @property
    def gintersect(self):
        """
        Gets the gintersect of this Filter.

        :return: The gintersect of this Filter.
        :rtype: list[list[str]]
        """
        return self._gintersect

    @gintersect.setter
    def gintersect(self, gintersect):
        """
        Sets the gintersect of this Filter.

        :param gintersect: The gintersect of this Filter.
        :type: list[list[str]]
        """

        self._gintersect = gintersect

    @property
    def notpwithin(self):
        """
        Gets the notpwithin of this Filter.

        :return: The notpwithin of this Filter.
        :rtype: list[list[str]]
        """
        return self._notpwithin

    @notpwithin.setter
    def notpwithin(self, notpwithin):
        """
        Sets the notpwithin of this Filter.

        :param notpwithin: The notpwithin of this Filter.
        :type: list[list[str]]
        """

        self._notpwithin = notpwithin

    @property
    def notgwithin(self):
        """
        Gets the notgwithin of this Filter.

        :return: The notgwithin of this Filter.
        :rtype: list[list[str]]
        """
        return self._notgwithin

    @notgwithin.setter
    def notgwithin(self, notgwithin):
        """
        Sets the notgwithin of this Filter.

        :param notgwithin: The notgwithin of this Filter.
        :type: list[list[str]]
        """

        self._notgwithin = notgwithin

    @property
    def notgintersect(self):
        """
        Gets the notgintersect of this Filter.

        :return: The notgintersect of this Filter.
        :rtype: list[list[str]]
        """
        return self._notgintersect

    @notgintersect.setter
    def notgintersect(self, notgintersect):
        """
        Sets the notgintersect of this Filter.

        :param notgintersect: The notgintersect of this Filter.
        :type: list[list[str]]
        """

        self._notgintersect = notgintersect

    @property
    def dateformat(self):
        """
        Gets the dateformat of this Filter.

        :return: The dateformat of this Filter.
        :rtype: str
        """
        return self._dateformat

    @dateformat.setter
    def dateformat(self, dateformat):
        """
        Sets the dateformat of this Filter.

        :param dateformat: The dateformat of this Filter.
        :type: str
        """

        self._dateformat = dateformat

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Filter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Propagation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field': 'str',
        'filter': 'Filter'
    }

    attribute_map = {
        'field': 'field',
        'filter': 'filter'
    }

    def __init__(self, field=None, filter=None):
        """
        Propagation - a model defined in Swagger
        """

        self._field = None
        self._filter = None

        if field is not None:
          self.field = field
        if filter is not None:
          self.filter = filter

    @property
    def field(self):
        """
        Gets the field of this Propagation.

        :return: The field of this Propagation.
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """
        Sets the field of this Propagation.

        :param field: The field of this Propagation.
        :type: str
        """

        self._field = field

    @property
    def filter(self):
        """
        Gets the filter of this Propagation.

        :return: The filter of this Propagation.
        :rtype: Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this Propagation.

        :param filter: The filter of this Propagation.
        :type: Filter
        """

        self._filter = filter

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Propagation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error import Error
from .expression import Expression
from .failure import Failure
from .filter import Filter
from .form import Form
from .page import Page
from .projection import Projection
from .propagation import Propagation
from .search import Search
from .tag import Tag
from .tag_request import TagRequest
from .update_response import UpdateResponse



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UpdateResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failures': 'list[Failure]',
        'failed': 'int',
        'updated': 'int',
        'progress': 'float',
        'id': 'str',
        'action': 'str',
        'propagated': 'int',
        'start_time': 'int',
        'end_time': 'int',
        'processing_time_ms': 'int',
        'label': 'str'
    }

    attribute_map = {
        'failures': 'failures',
        'failed': 'failed',
        'updated': 'updated',
        'progress': 'progress',
        'id': 'id',
        'action': 'action',
        'propagated': 'propagated',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'processing_time_ms': 'processingTimeMs',
        'label': 'label'
    }

    def __init__(self, failures=None, failed=None, updated=None, progress=None, id=None, action=None, propagated=None, start_time=None, end_time=None, processing_time_ms=None, label=None):
        """
        UpdateResponse - a model defined in Swagger
        """

        self._failures = None
        self._failed = None
        self._updated = None
        self._progress = None
        self._id = None
        self._action = None
        self._propagated = None
        self._start_time = None
        self._end_time = None
        self._processing_time_ms = None
        self._label = None

        if failures is not None:
          self.failures = failures
        if failed is not None:
          self.failed = failed
        if updated is not None:
          self.updated = updated
        if progress is not None:
          self.progress = progress
        if id is not None:
          self.id = id
        if action is not None:
          self.action = action
        if propagated is not None:
          self.propagated = propagated
        if start_time is not None:
          self.start_time = start_time
        if end_time is not None:
          self.end_time = end_time
        if processing_time_ms is not None:
          self.processing_time_ms = processing_time_ms
        if label is not None:
          self.label = label

    @property
    def failures(self):
        """
        Gets the failures of this UpdateResponse.

        :return: The failures of this UpdateResponse.
        :rtype: list[Failure]
        """
        return self._failures

    @failures.setter
    def failures(self, failures):
        """
        Sets the failures of this UpdateResponse.

        :param failures: The failures of this UpdateResponse.
        :type: list[Failure]
        """

        self._failures = failures

    @property
    def failed(self):
        """
        Gets the failed of this UpdateResponse.

        :return: The failed of this UpdateResponse.
        :rtype: int
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """
        Sets the failed of this UpdateResponse.

        :param failed: The failed of this UpdateResponse.
        :type: int
        """

        self._failed = failed

    @property
    def updated(self):
        """
        Gets the updated of this UpdateResponse.

        :return: The updated of this UpdateResponse.
        :rtype: int
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """
        Sets the updated of this UpdateResponse.

        :param updated: The updated of this UpdateResponse.
        :type: int
        """

        self._updated = updated

    @property
    def progress(self):
        """
        Gets the progress of this UpdateResponse.

        :return: The progress of this UpdateResponse.
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """
        Sets the progress of this UpdateResponse.

        :param progress: The progress of this UpdateResponse.
        :type: float
        """

        self._progress = progress

    @property
    def id(self):
        """
        Gets the id of this UpdateResponse.

        :return: The id of this UpdateResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UpdateResponse.

        :param id: The id of this UpdateResponse.
        :type: str
        """

        self._id = id

    @property
    def action(self):
        """
        Gets the action of this UpdateResponse.

        :return: The action of this UpdateResponse.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this UpdateResponse.

        :param action: The action of this UpdateResponse.
        :type: str
        """
        allowed_values = ["ADD", "REMOVE", "REMOVEALL"]
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def propagated(self):
        """
        Gets the propagated of this UpdateResponse.

        :return: The propagated of this UpdateResponse.
        :rtype: int
        """
        return self._propagated

    @propagated.setter
    def propagated(self, propagated):
        """
        Sets the propagated of this UpdateResponse.

        :param propagated: The propagated of this UpdateResponse.
        :type: int
        """

        self._propagated = propagated

    @property
    def start_time(self):
        """
        Gets the start_time of this UpdateResponse.

        :return: The start_time of this UpdateResponse.
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this UpdateResponse.

        :param start_time: The start_time of this UpdateResponse.
        :type: int
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this UpdateResponse.

        :return: The end_time of this UpdateResponse.
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this UpdateResponse.

        :param end_time: The end_time of this UpdateResponse.
        :type: int
        """

        self._end_time = end_time

    @property
    def processing_time_ms(self):
        """
        Gets the processing_time_ms of this UpdateResponse.

        :return: The processing_time_ms of this UpdateResponse.
        :rtype: int
        """
        return self._processing_time_ms

    @processing_time_ms.setter
    def processing_time_ms(self, processing_time_ms):
        """
        Sets the processing_time_ms of this UpdateResponse.

        :param processing_time_ms: The processing_time_ms of this UpdateResponse.
        :type: int
        """

        self._processing_time_ms = processing_time_ms

    @property
    def label(self):
        """
        Gets the label of this UpdateResponse.

        :return: The label of this UpdateResponse.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this UpdateResponse.

        :param label: The label of this UpdateResponse.
        :type: str
        """

        self._label = label

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UpdateResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.error import Error
from .models.expression import Expression
from .models.failure import Failure
from .models.filter import Filter
from .models.form import Form
from .models.page import Page
from .models.projection import Projection
from .models.propagation import Propagation
from .models.search import Search
from .models.tag import Tag
from .models.tag_request import TagRequest
from .models.update_response import UpdateResponse

# import apis into sdk package
from .apis.status_api import StatusApi
from .apis.write_api import WriteApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
